/**
 * This interface specifies the behaviour of the
 * ConnectionHandler. It is used in conjuction 
 * with the ServletConnection to achieve the 
 * desired communication.
 *
 * @author Lars Samuelsson
 */
public interface ConnectionHandler {
    /**
     * Used when handshaking to get the connection data.
     * 
     * @return The connection data to use when handshaking.
     */
    public Object getConnectionData();
    /**
     * The response given in a handshake procedure.
     * 
     * @param response The response from a handshake.
     */
    public void setConnectionResponse(Object response);
    /**
     * Used to retrieve the current connection status.
     * 
     * @return true when a connection has been established
     *         and false otherwise.
     */
    public boolean isConnected();
    /**
     * Used to set the connection status.
     * 
     * @param connected true or false.
     */
    public void setConnected(boolean connected);
    /**
     * Used to handle data recieved by the ServletConnection.
     *
     * @param data The data to be handled.
     */
    public void handleData(Object data);
}
