import java.util.Vector;

/**
 * This class can be used to keep a history
 * of objects. The history has a limited size
 * and the when its capacity is reached the
 * oldest entries will be removed as new are
 * added.
 * 
 * @author Lars Samuelsson
 */
public class History {
   // holds the entries
   private Vector history;
   // the number of entries the history can hold
   private int capacity;
   /**
    * Creates a history with the given capacity.
    * 
    * @param capacity The number of entries the history can hold.
    */
   public History(int capacity) {
      this.capacity = capacity;
      history = new Vector(capacity);
   }
   /**
    * Adds an entry to the history.
    * 
    * @param entry The object to add.
    */
   public void addEntry(Object entry) {
      if(history.size() == capacity)
	history.removeElementAt(0);
      history.addElement(entry);
   }
   /**
    * Fetches a specific history entry. Note that 
    * the history is circular and the entry at 
    * history.size() is the same as the 0th entry.
    * 
    * @param index The index of the entry to get, 
    *              where 0 is the last entry.
    * @return      The object at the given index.
    */
   public Object entryAt(int index) {
      return history.elementAt((size() - index) % size());
   }
   /**
    * Replaces a specific entry in the history with another.
    * 
    * @param index The index of the entry to replace.
    * @param entry The new entry to take its place.
    */
   public void replaceEntry(int index, Object entry) {
      int imod = (size() - index) % size();
      history.removeElementAt(imod);
      history.insertElementAt(entry, imod);
   }
   /**
    * Used to clear the history.
    */
   public void clear() {
      history.removeAllElements();
   }
   /**
    * Used to get the current size of the history.
    * 
    * @return The number of stored entries.
    */
   public int size() {
      return history.size();
   }
}
